==> java-cxf-cdi-server-generator-0.12.3.tgz: package/test-output/one-of-no-discriminator.yml/src/main/java/com/example/model/Dog.java <==
package com.example.model;

@io.swagger.annotations.ApiModel(value = "Dog")
@javax.xml.bind.annotation.XmlRootElement(name = "Dog")
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-cdi-server-generator", date = "2021-02-17T03:31:42.961Z")
public class Dog implements java.io.Serializable, com.example.model.MyResponseType {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.String bark = null;
	
	/**
	 */
	public Dog name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Dog bark(java.lang.String bark) {
		setBark(bark);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("bark")
	public java.lang.String getBark() {
		return this.bark;
	}
	public void setBark(java.lang.String bark) {
		this.bark = bark;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Dog dog = (Dog) o;
		return java.util.Objects.equals(this.name, dog.name) &&
				java.util.Objects.equals(this.bark, dog.bark);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.bark);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Dog {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    bark: ").append(toIndentedString(this.bark)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-cdi-server-generator-0.12.4.tgz: package/test-output/one-of-no-discriminator.yml/src/main/java/com/example/model/Dog.java <==
package com.example.model;

@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-cdi-server-generator", date = "2021-03-09T02:58:17.554Z")
@io.swagger.annotations.ApiModel(value = "Dog")
@javax.xml.bind.annotation.XmlRootElement(name = "Dog")
public class Dog implements java.io.Serializable, com.example.model.MyResponseType {

	private static final long serialVersionUID = 1L;
	private java.lang.String name = null;
	private java.lang.String bark = null;
	
	/**
	 */
	public Dog name(java.lang.String name) {
		setName(name);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("name")
	public java.lang.String getName() {
		return this.name;
	}
	public void setName(java.lang.String name) {
		this.name = name;
	}
	
	/**
	 */
	public Dog bark(java.lang.String bark) {
		setBark(bark);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("bark")
	public java.lang.String getBark() {
		return this.bark;
	}
	public void setBark(java.lang.String bark) {
		this.bark = bark;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Dog dog = (Dog) o;
		return java.util.Objects.equals(this.name, dog.name)
				&& java.util.Objects.equals(this.bark, dog.bark);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.name, this.bark);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Dog {\n");
		
		sb.append("    name: ").append(toIndentedString(this.name)).append("\n");
		sb.append("    bark: ").append(toIndentedString(this.bark)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
